# v0.1.0 - 2021/06/01

## Added

- Basic set of modules: `InitializeTF`, `Classifier`, `MLP`, `Tensorboard`, `Train`, `Save`, `images.CIFAR100`, `images.CIFAR10`, `images.ImagenetDirectory`, `images.MNIST`, `images.Encoder`, `images.MobileNetV2`, `images.ResNet`
